diff --git a/usr/local/www/themes/pfsense_ng_fs/loader.js b/usr/local/www/themes/pfsense_ng_fs/loader.js
index 0531780fb0..1f7fc319a2 100644
--- a/usr/local/www/themes/pfsense_ng_fs/loader.js
+++ b/usr/local/www/themes/pfsense_ng_fs/loader.js
@@ -228,21 +228,24 @@ jQuery(document).ready(function ()
///////////////////////////////////////////
// jQuery code for columns / widgets part 2
///////////////////////////////////////////
-
- // correct the css for column 2
- jQuery('#col2').css("float","left");
-
+
// insert add/delete column buttons
jQuery('
').insertBefore('#niftyOutter.fakeClass');
-
- // Make a copy of the current state of columns on page load
- for ( var i = 1; i <= noCols; i = i + 1 )
- {
- var contents = jQuery('#col' + i ).html();
- existing.push( contents );
- }
- finishedResizing(); // on page load correct display of columns to fit
+ if ( jQuery('#columnModifier').length > 0 ) // only perform resizing on the dashboard page
+ {
+ // correct the css for column 2
+ jQuery('#col2').css("float","left");
+
+ // Make a copy of the current state of columns on page load
+ for ( var i = 1; i <= noCols; i = i + 1 )
+ {
+ var contents = jQuery('#col' + i ).html();
+ existing.push( contents );
+ }
+
+ finishedResizing(); // on page load correct display of columns to fit
+ }
// on click add a new column and change column widths
jQuery('#addCol').click(function()